import { AwsCredentialsProvider } from './aws-credentials';
import * as github from './workflows-model';
/**
 * Assembly artifact options applied to all jobs using artifacts in the workflow.
 */
export declare abstract class AssemblyArtifactOptions {
    /**
     * Configure download assembly steps.
     *
     * @default - By default, it uses `actions/download-artifact@v3`.
     */
    abstract downloadAssemblySteps(targetName: string, targetDir: string): github.JobStep[];
    /**
     * Configure upload assembly steps.
     *
     * @default - By default, it uses `actions/upload-artifact@v3`.
     */
    abstract uploadAssemblySteps(sourceName: string, sourceDir: string): github.JobStep[];
}
/**
 * Github assembly artifact options uses built-in `upload-artifact/download-artifact`
 * for artifacts handling.
 */
export declare class GithubAssemblyArtifactOptions extends AssemblyArtifactOptions {
    constructor();
    downloadAssemblySteps(targetName: string, targetDir: string): github.JobStep[];
    uploadAssemblySteps(sourceName: string, sourceDir: string): github.JobStep[];
}
/**
 * Props for `S3AssemblyArtifactOptions`.
 */
export interface S3AssemblyArtifactOptionsProps {
    readonly bucket: string;
    readonly region: string;
    readonly seed?: string;
    readonly awsCreds?: AwsCredentialsProvider;
    readonly assumeRoleArn?: string;
}
/**
 * S3 assembly artifact options uses a given S3 bucket for artifacts handling.
 */
export declare class S3AssemblyArtifactOptions extends AssemblyArtifactOptions {
    private readonly awsCredsStep;
    private readonly bucket;
    private readonly seed;
    constructor(props: S3AssemblyArtifactOptionsProps);
    downloadAssemblySteps(targetName: string, targetDir: string): github.JobStep[];
    uploadAssemblySteps(sourceName: string, sourceDir: string): github.JobStep[];
}
